"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var arrayValueGenerator_1 = require("../generators/arrayValueGenerator");
var primitiveValueGenerator_1 = require("../generators/primitiveValueGenerator");
var unionValueGenerator_1 = require("../generators/unionValueGenerator");
var typeUtils_1 = require("../utils/typeUtils");
var genericValueGenerator_1 = require("../generators/genericValueGenerator");
var TypeResolver = /** @class */ (function () {
    function TypeResolver(baseValueGenerator) {
        this.arrayGenerator = new arrayValueGenerator_1.ArrayValueGenerator(baseValueGenerator);
        this.primitiveGenerator = new primitiveValueGenerator_1.PrimitiveValueGenerator(baseValueGenerator);
        this.unionGenerator = new unionValueGenerator_1.UnionValueGenerator(baseValueGenerator);
        this.genericGenerator = new genericValueGenerator_1.GenericValueGenerator(baseValueGenerator);
        this.getGenerator = this.getGenerator.bind(this);
        this.resolve = this.resolve.bind(this);
    }
    TypeResolver.prototype.getGenerator = function (type) {
        var generator;
        if (typeUtils_1.isUnion(type) && !typeUtils_1.isGeneric(type)) {
            generator = this.unionGenerator;
        }
        else if (typeUtils_1.isPrimitive(type) && !typeUtils_1.isGeneric(type)) {
            generator = this.primitiveGenerator;
        }
        else if (typeUtils_1.isArray(type) && !typeUtils_1.isGeneric(type)) {
            generator = this.arrayGenerator;
        }
        else if (typeUtils_1.isGeneric(type)) {
            generator = this.genericGenerator;
        }
        return generator;
    };
    TypeResolver.prototype.resolve = function (type) {
        return this.getGenerator(type);
    };
    return TypeResolver;
}());
exports.TypeResolver = TypeResolver;
