"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_morph_1 = require("ts-morph");
function getTypeArgumentsOfExtendedType(extendedType) {
    var mappedTypes = {};
    var symbol = extendedType.getType().getSymbol();
    var argumentBaseTypes = symbol
        ? symbol
            .getDeclaredType()
            .getTypeArguments()
            .map(function (argument) { return argument.getText(); })
        : [];
    var argumentGivenTypes = extendedType.getTypeArguments().map(function (typeArgument) { return typeArgument.getText(); });
    argumentBaseTypes.forEach(function (baseType, index) {
        mappedTypes[baseType] = argumentGivenTypes[index];
    });
    return mappedTypes;
}
exports.getTypeArgumentsOfExtendedType = getTypeArgumentsOfExtendedType;
function getPropertiesOfInterfaceDeclaration(_interface) {
    return _interface.getProperties().map(function (property) {
        var typeName = property.getTypeNode().getText();
        return {
            type: typeName,
            name: property.getName(),
            isGeneric: property.getType().isTypeParameter()
        };
    });
}
exports.getPropertiesOfInterfaceDeclaration = getPropertiesOfInterfaceDeclaration;
function getExtendedPropertiesOfInterfaceDeclaration(_interface) {
    var properties = [];
    _interface.getExtends().forEach(function (extended) {
        var typeArguments = getTypeArgumentsOfExtendedType(extended);
        return extended
            .getType()
            .getProperties()
            .forEach(function (property) {
            var propertyType = property.getValueDeclaration().getType();
            var propertyTypeName = propertyType.getText(undefined, ts_morph_1.TypeFormatFlags.InTypeAlias);
            properties.push({
                type: typeArguments[propertyTypeName] || propertyTypeName,
                name: property.getName(),
                isGeneric: propertyType.isTypeParameter()
            });
        });
    });
    return properties;
}
exports.getExtendedPropertiesOfInterfaceDeclaration = getExtendedPropertiesOfInterfaceDeclaration;
function getMembersOfEnumDeclaration(_enum) {
    var properties = [];
    _enum.getMembers().forEach(function (member) {
        properties.push({
            type: member.getType().getText(undefined, ts_morph_1.TypeFormatFlags.InTypeAlias),
            name: member.getName(),
            isGeneric: member.getType().isTypeParameter(),
            value: member.getValue()
        });
    });
    return properties;
}
exports.getMembersOfEnumDeclaration = getMembersOfEnumDeclaration;
