"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ts_morph_1 = require("ts-morph");
var helpers_1 = require("./helpers");
var Declaration;
(function (Declaration) {
    Declaration[Declaration["Interface"] = 0] = "Interface";
    Declaration[Declaration["Enum"] = 1] = "Enum";
    Declaration[Declaration["Type"] = 2] = "Type";
})(Declaration = exports.Declaration || (exports.Declaration = {}));
var TypeChecker = /** @class */ (function () {
    function TypeChecker(files) {
        this.project = new ts_morph_1.Project();
        this.project.addSourceFilesAtPaths(files);
        this.generateContainer = this.generateContainer.bind(this);
        this.getContainerItemsFromFiles = this.getContainerItemsFromFiles.bind(this);
    }
    TypeChecker.prototype.generateContainer = function () {
        return this.getContainerItemsFromFiles();
    };
    TypeChecker.prototype.getContainerItemsFromFiles = function () {
        var _this = this;
        var items = [];
        var files = this.project.getSourceFiles();
        files.forEach(function (file) {
            file.getInterfaces().forEach(function (_interface) { return items.push(_this.mapInterfaceProperties(_interface)); });
            file
                .getEnums()
                .filter(function (_enum) { return !_enum.isConstEnum(); })
                .forEach(function (_enum) { return items.push(_this.mapEnumMembers(_enum)); });
        });
        return items;
    };
    TypeChecker.prototype.mapInterfaceProperties = function (_interface) {
        var properties = [];
        var type = Declaration.Interface;
        var name = _interface.getName();
        var typeParameters = _interface.getTypeParameters().map(function (param) { return param.getText(); });
        var isGeneric = typeParameters.length > 0;
        properties = properties.concat(helpers_1.getPropertiesOfInterfaceDeclaration(_interface), helpers_1.getExtendedPropertiesOfInterfaceDeclaration(_interface));
        return { type: type, name: name, properties: properties, typeParameters: typeParameters, isGeneric: isGeneric };
    };
    TypeChecker.prototype.mapEnumMembers = function (_enum) {
        var properties = [];
        var type = Declaration.Enum;
        var name = _enum.getName();
        var typeParameters = [];
        var isGeneric = typeParameters.length > 0;
        properties = properties.concat(helpers_1.getMembersOfEnumDeclaration(_enum));
        return { type: type, name: name, properties: properties, typeParameters: typeParameters, isGeneric: isGeneric };
    };
    return TypeChecker;
}());
exports.TypeChecker = TypeChecker;
